
import { full as emoji } from 'markdown-it-emoji'

import MarkdownItSubscript from 'markdown-it-sub'
import MarkdownItSuperscript from 'markdown-it-sup'
import MarkdownItFootnote from 'markdown-it-footnote'
import MarkdownItDeflist from 'markdown-it-deflist'
import MarkdownItAbbreviation from 'markdown-it-abbr'
import MarkdownItInsert from 'markdown-it-ins'
import MarkdownItMark from 'markdown-it-mark'
import MarkdownItKatex from '@iktakahiro/markdown-it-katex'
import MarkdownItTasklists from 'markdown-it-task-lists'
import MarkdownItLatex from 'markdown-it-latex'
import MarkdownItContainer from 'markdown-it-container'
import MarkdownItGithubToc from 'markdown-it-github-toc'
import MarkdownItSourceMap from 'markdown-it-source-map'

import MarkdownItHighlight from './customPLugins/markdown-it-highlight.js'

import 'github-markdown-css'
import 'markdown-it-latex/dist/index.css'
import './markdown-it-vue.scss'

const DEFAULT_OPTIONS_LINK_ATTRIBUTES = {
  attrs: {
    target: '_blank',
    rel: 'noopener'
  }
}
const DEFAULT_OPTIONS_KATEX = { throwOnError: false, errorColor: '#cc0000' }
const DEFAULT_OPTIONS_TASKLISTS = null
const DEFAULT_OPTIONS_GITHUBTOC = {
  tocFirstLevel: 2,
  tocLastLevel: 3,
  tocClassName: 'toc',
  anchorLinkSymbol: '',
  anchorLinkSpace: false,
  anchorClassName: 'anchor',
  anchorLinkSymbolClassName: 'octicon octicon-link'
}

function copyPlugin(md) {
  const oldFence = md.renderer.rules.fence
  md.codeMap = {}
  md.renderer.rules.fence = (tokens, idx, options, env, instance) => {
    md.codeMap[idx] = tokens[idx].content
    return `<div class="md-container-code-wrapper ">
    <button class="md-container-code-copy el-button el-button--default el-button--mini" data-copy data-token-idx=${idx}>复制</button>
    ${oldFence(tokens, idx, options, env, instance)}
  </div>`
  }
}

const plugins = [
  [emoji],
  [MarkdownItSubscript],
  [MarkdownItSuperscript],
  [MarkdownItFootnote],
  [MarkdownItDeflist],
  [MarkdownItAbbreviation],
  [MarkdownItInsert],
  [MarkdownItMark],
  [MarkdownItKatex, DEFAULT_OPTIONS_KATEX],
  [MarkdownItTasklists,DEFAULT_OPTIONS_TASKLISTS],
  [MarkdownItLatex,],
  [MarkdownItGithubToc,DEFAULT_OPTIONS_GITHUBTOC],
  [MarkdownItSourceMap,],
  [MarkdownItHighlight],

  [MarkdownItContainer,'info',{
    validate: function(params) {
      return params.trim() === 'info'
    },
    render: (tokens, idx) => {
      if (tokens[idx].nesting === 1) {
        const icon = `<i class="markdown-it-vue-alert-icon markdown-it-vue-alert-icon-info"><svg viewBox="64 64 896 896" data-icon="info-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm32 664c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V456c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272zm-32-344a48.01 48.01 0 0 1 0-96 48.01 48.01 0 0 1 0 96z"></path></svg></i>`
        return `<div class="markdown-it-vue-alter markdown-it-vue-alter-info">${icon}`
      } else {
        return '</div>'
      }
    }
  }],
  [MarkdownItContainer,'success',{
    validate: function(params) {
      return params.trim() === 'success'
    },
    render: (tokens, idx) => {
      if (tokens[idx].nesting === 1) {
        const icon = `<i class="markdown-it-vue-alert-icon markdown-it-vue-alert-icon-success"><svg viewBox="64 64 896 896" data-icon="check-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm193.5 301.7l-210.6 292a31.8 31.8 0 0 1-51.7 0L318.5 484.9c-3.8-5.3 0-12.7 6.5-12.7h46.9c10.2 0 19.9 4.9 25.9 13.3l71.2 98.8 157.2-218c6-8.3 15.6-13.3 25.9-13.3H699c6.5 0 10.3 7.4 6.5 12.7z"></path></svg></i>`
        return `<div class="markdown-it-vue-alter markdown-it-vue-alter-success">${icon}`
      } else {
        return '</div>'
      }
    }
  }],
  [MarkdownItContainer,'error',{
    validate: function(params) {
      return params.trim() === 'error'
    },
    render: (tokens, idx) => {
      if (tokens[idx].nesting === 1) {
        const icon = `<i class="markdown-it-vue-alert-icon markdown-it-vue-alert-icon-error"><svg viewBox="64 64 896 896" data-icon="close-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm165.4 618.2l-66-.3L512 563.4l-99.3 118.4-66.1.3c-4.4 0-8-3.5-8-8 0-1.9.7-3.7 1.9-5.2l130.1-155L340.5 359a8.32 8.32 0 0 1-1.9-5.2c0-4.4 3.6-8 8-8l66.1.3L512 464.6l99.3-118.4 66-.3c4.4 0 8 3.5 8 8 0 1.9-.7 3.7-1.9 5.2L553.5 514l130 155c1.2 1.5 1.9 3.3 1.9 5.2 0 4.4-3.6 8-8 8z"></path></svg></i>`
        return `<div class="markdown-it-vue-alter markdown-it-vue-alter-error">${icon}`
      } else {
        return '</div>'
      }
    }
  }],
  [copyPlugin]
]

export const usePlugins = (markdownInstance, customPLugins) => {
  plugins.forEach(plugin => {
    markdownInstance.use(...plugin)
  })
  customPLugins.forEach(plugin => {
    markdownInstance.use(plugin)
  })
}