
const parseValue=val=>{
  if(!val) return val
  val = decodeURIComponent(val)
  return /^\d+$/.test(val) ? parseFloat(val) : val
}

export function getPropsFromUrl(key) {
  const params = new URLSearchParams(window.location.search)
  if (Array.isArray(key)) {
    return key.map(k => parseValue(params.get(k)) )
  }
  return parseValue(params.get(k))
}

export function getAuthFields() {
  let [token, apiKey] = getPropsFromUrl(['token', 'apiKey'])
  if(token){
    token = token.startsWith('Bearer') ? token : `Bearer ${token}`
  }

  return {
    token,
    apiKey
  }
}


export const clearNode = (node) => {
  while (node.firstChild) {
    node.removeChild(node.firstChild)
  }
}

export const createEl = (tagName, { className, parent }) => {
  const el = document.createElement(tagName)
  if (className) {
    el.classList.add(className)
  }
  if (parent) {
    parent.appendChild(el)
  }
  return el
}

export function sleep(time = 100) {
  return new Promise(r => setTimeout(r, time))
}

export function escapeStringRegexp(string) {
	if (typeof string !== 'string') {
		throw new TypeError('Expected a string');
	}

	// Escape characters with special meaning either inside or outside character sets.
	// Use a simple backslash escape when it’s always valid, and a `\xnn` escape when the simpler form would be disallowed by Unicode patterns’ stricter grammar.
	return string
		.replace(/[|\\{}()[\]^$+*?.]/g, '\\$&')
		.replace(/-/g, '\\x2d');
}

export function debounce(func, wait) {
  let timeoutId;

  // 返回一个新的防抖函数
  return function debounced(...args) {
    // 清除之前设置的定时器
    clearTimeout(timeoutId);

    // 设置新的定时器，在wait毫秒后执行func，并保存定时器ID
    timeoutId = setTimeout(() => {
      func.apply(this, args);
    }, wait);
  };
}

export function get(obj, path, defaultValue = undefined) {
  if (obj == null) {
    return defaultValue;
  }

  const pathArray = Array.isArray(path) ? path : path.replaceAll('[', '.').replaceAll(']', '').split('.');
  let current = obj;

  for (let i = 0; i < pathArray.length; i++) {
    const key = pathArray[i];

    if (current[key] === undefined || current[key] === null) {
      // 如果到达了空（null或undefined）或者未定义的属性，则返回默认值
      return defaultValue;
    }

    current = current[key];
  }

  return current;
}
