import request from '@common/utils/request/pc'
import { getAuthFields } from '@common/utils/index.js'
import { stringify } from 'qs'
/**
  获取 chat 的初始化数据
  guid
  questions
  scenes
  promps
  knowledges
  @param {number }type   chat 界面  1 知识库页 2
*/
export function getInitChatData(type) {
  return request({
    url: 'api/chat/prompt',
    method: 'get',
    params: {
      type
    }
  })
}

export function getChatPreQuestion({ useType, useValue }) {
  return request({
    url: 'api/promptQuestion',
    method: 'get',
    params: {
      useType,
      useValue
    }
  })
}
/*
  提示问题查询 参数为 分类
*/
export function getPromptListBySensId(sceneId) {
  return request({
    url: 'api/prompt/queryAllList',
    method: 'get',
    params: {
      sceneId
    }
  })
}

/*
  根据类型获取模板列表
*/
export function getPromptListByType(type) {
  return request({
    url: 'api/prompt/queryListByType',
    method: 'get',
    params: {
      type
    }
  })
}

/*
  获取聊天列表
*/
export function getAllChatList() {
  return request({
    url: 'api/llmChat/queryAllList',
    method: 'get'
  })
}

/*
  获取 chatList
*/
export function getChatList(options) {
  const { page = 0, size = 20, sort = 'id,desc', sourceType, sourceValue } = options || {}
  return request({
    url: 'api/llmChat',
    method: 'get',
    params: {
      page,
      size,
      sort,
      sourceType,
      sourceValue
    }
  })
}

export function delChat(ids) {
  return request({
    url: 'api/llmChat',
    method: 'delete',
    data: Array.isArray(ids) ? ids : [ids]
  })
}
/*
  更新Chat 的 消息状态   点赞 踩
*/
export function updateChatMessageHistory(data) {
  return request({
    url: 'api/chatHistory',
    method: 'put',
    data
  })
}

/*
  通过 chatId 获取 消息历史
*/
export function getMessageByChatId(chatId) {
  return request({
    url: 'api/chatHistory/queryAllList',
    method: 'get',
    params: {
      chatId
    }
  })
}

export function getSourceFileUrl({  fileId, needToken = false }) {
  let url = `/api/kb/file/downloadOnlyOffice/${fileId}`
  const data = {}

  if (needToken) {
    const { token, apiKey } = getAuthFields()
    if (token) {
      data['Authorization'] = token
    }

    if (apiKey) {
      data['apiKey'] = apiKey
    }

  }
  return `${url}${stringify(data, { addQueryPrefix: true })}`
}

/*
  获取统计数据
*/

export function getChatStatics() {
  return request({
    url: 'api/chatHistory/queryStatByKnowledge',
    method: 'get'
  })
}


export function uploadFile(data) {
  const { file, fileType = 'user' } = data || {}
  const formData = new FormData()
  formData.append('files', file)
  formData.append('fileType', fileType)
  return request({
    url: 'api/kb/file/uploadFile',
    method: 'post',
    data: formData
  })
}

export function getFileList(data) {
  const { page = 0, size = 20, sort = 'id,desc', fileType = 'user' } = data || {}
  return request({
    url: 'api/kb/file',
    method: 'get',
    params: { page, size, sort, fileType }
  })
}
