import request from '@common/utils/request/pc'
import { clearNode, createEl,} from '@common/utils/index.js'

export class TextController {
  static cache = {}
  constructor(options) {
    this.$options = options
  }

  loadFileContent() {
    const { url } = this.$options
    const cache = TextController.cache
    const loadTask = cache[url] || request(url)
    cache[url] = loadTask
    return loadTask
  }
  async init() {
    const fileContent = await this.loadFileContent()
    this.fileContent = fileContent
  }
  creatSubNode({ text, isHighlight, parent }) {
    const { highlightClassName = 'highlight' } = this.$options
    let node
    if (isHighlight) {
      node = document.createElement('span')
      node.classList.add(highlightClassName)
      node.innerText = text
    } else {
      node = document.createTextNode(text)
    }

    if (parent) {
      parent.append(node)
    }
    return node
  }
  async renderTextLayer() {
    const { fileContent } = this
    const { keyword, container, lineClassName } = this.$options || {}
    container && clearNode(container)

    const pureFileContent = (fileContent || keyword).replaceAll('\n', '')
    const pureKeyword = keyword.replaceAll('\n', '')
    const pureKeywordIdx = pureFileContent.indexOf(pureKeyword)
    const pureKeywordEndIdx = pureKeywordIdx + pureKeyword.length
    const fileContentChars = [...(fileContent || keyword)]
    if (!fileContentChars.length) return

    let tmpStrArr = []
    let purCharIdx = 0
    let line = createEl('div', {
      className: lineClassName,
      parent: container
    })
    for (let i = 0; i < fileContentChars.length; i++) {
      const char = fileContentChars[i]
      if (char === '\n') {
        if (tmpStrArr.length) {
          this.creatSubNode({
            text: tmpStrArr.join(''),
            isHighlight: purCharIdx > pureKeywordIdx && purCharIdx < pureKeywordEndIdx,
            parent: line
          })
          tmpStrArr = []
        }
        line = createEl('div', {
          className: lineClassName,
          parent: container
        })
        continue
      }
      purCharIdx++
      tmpStrArr.push(char)
      if (purCharIdx === pureKeywordIdx) {
        if (tmpStrArr.length) {
          this.creatSubNode({
            text: tmpStrArr.join(''),
            isHighlight: false,
            parent: line
          })
          tmpStrArr = []
        }
      } else if (purCharIdx === pureKeywordEndIdx) {
        if (tmpStrArr.length) {
          this.creatSubNode({
            text: tmpStrArr.join(''),
            isHighlight: true,
            parent: line
          })
          tmpStrArr = []
        }
      }
    }
  }

  async scrollToHighlight() {
    const { container, highlightClassName = 'highlight' } = this.$options
    if (!container || !highlightClassName) return
    const firstHighlightNode = container.querySelector(`.${highlightClassName}`)
    if (firstHighlightNode && firstHighlightNode.scrollIntoView) {
      firstHighlightNode.scrollIntoView({
        behavior: 'smooth',
        block: 'center'
      })
    }
  }
}

