
import { stringify } from 'qs'
import { CHAT_SOURCE_TYPE } from '../constants'
const baseURL = import.meta.env.MODE === 'development' ? import.meta.env.VITE_VUE_APP_BASE_API : '/'

import debug from './debug'
import { getAuthFields } from '@common/utils/index.js'
class StreamMsg {
  /**
   * options
   * options.message
   * options
   */
  constructor(options) {
    this.options = options
    this.init()
  }

  getSseUrl(options) {
    const { message, currentPromp, currentKbKnowledge, sourceType, chatId } = options
    const { token, apiKey } = getAuthFields()
    // chatId
    // 首页 llmPromptId     知识库问答  kbKnowledgeId
    let url = `${baseURL}api/chat/getSSEAnswer`
    const data = {
      question: message,
      chatId,

    }
    if (apiKey) {
      data['apiKey'] = apiKey
    }
    if (token) {
      data['authorization'] = token.replace('Bearer ', '')
    }

    if (sourceType === CHAT_SOURCE_TYPE.aigc && currentPromp) {
      data['llmPromptId'] = currentPromp.id
    }
    if (sourceType === CHAT_SOURCE_TYPE.knowledge && currentKbKnowledge) {
      data['kbKnowledgeId'] = currentKbKnowledge.id
    }
    return `${url}${stringify(data, { addQueryPrefix: true })}`
  }
  init() {
    const { message, onOpen, onStream, onFinish, currentPromp, currentKbKnowledge, chatId, sourceType } = this.options
    debug.log('初始化流式接口', currentPromp)
    this.sse = new EventSource(this.getSseUrl({
      message, currentPromp,
      chatId, currentKbKnowledge, sourceType
    }))
    this.sse.addEventListener('open', e => {
      debug.log('open----', e)
      if (onOpen) onOpen(e)
    })
    this.sse.addEventListener('add', e => {
      if (onStream) onStream(e.data)
    })
    this.sse.addEventListener('finish', e => {
      debug.log('finish', e)
      this.close()
      if (onFinish) onFinish(e)
    })
    this.sse.addEventListener('error', e => {
      debug.log('error----', e)
      this.close()
      if (onFinish) onFinish(e)
    })
  }

  close() {
    this.sse.close()
  }
}

export default StreamMsg
